@@ -7,7 +7,7 @@
 /* beam.c --- frame-synchronous beam search on 1st pass */
 /* use (1-best|word-pair) with static tree structure */
 
-/* $Id: beam.c,v 1.10 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: beam.c,v 1.13 2003/12/22 09:39:23 ri Exp $ */
 
 #include <julius.h>
 
@@ -39,7 +39,7 @@ generate_lattice(
      int endtime,		/* word end frame to lookup */
      WORD_ID wid,		/* word ID to lookup */
      BACKTRELLIS *bt,		/* backtrellis structure */
-     WORD_INFO winfo		/* used dictionary (for word output) */
+     WORD_INFO *winfo		/* used dictionary (for word output) */
      )
 {
   TRELLIS_ATOM *ta, *ta_last;
@@ -655,13 +655,31 @@ static WORD_ID last_tre_word;
 static boolean first_sparea;	/* TRUE if this is the first pause segment in a input stream */
 static int sp_duration;		/* number of sp frame to be durated */
 
+/* return if word 'w' is sp word */
+/* sp word: word that has only 1 phoneme of hmminfo->sp */
+boolean
+is_sil(WORD_ID w, WORD_INFO *winfo, HTK_HMM_INFO *hmm)
+{
+  /* num of phones should be 1 */
+  if (winfo->wlen[w] > 1) return FALSE;
+
+  /* short pause (specified by "-spmodel") */
+  if (winfo->wseq[w][0] == hmm->sp) return TRUE;
+
+  /* head/tail sil */
+  if (w == winfo->head_silwid || w == winfo->tail_silwid) return TRUE;
+
+  /* otherwise */
+  return FALSE;
+}
+
 /* $B%7%g!<%H%]!<%:$NO"B3$r8+$F(B, $BF~NO$N@ZL\$r8!=P$9$k(B */
 /* $BBh#1%Q%9$,#1%U%l!<%`?J$`$4$H$K8F$P$l$k(B */
 /* watch duration of short-pause words and detect end of input segment */
 /* called for every frame in 1st pass */
 /* return value: TRUE if segment end here, FALSE if continue */
 static boolean
-detect_end_of_segment(BACKTRELLIS *backtrellis, int time, WORD_INFO *winfo)
+detect_end_of_segment(BACKTRELLIS *backtrellis, int time, WCHMM_INFO *wchmm)
 {
   TRELLIS_ATOM *tre;
   LOGPROB maxscore = LOG_ZERO;
@@ -681,8 +699,7 @@ detect_end_of_segment(BACKTRELLIS *backtrellis, int time, WORD_INFO *winfo)
   if (tremax == NULL) {	/* no word end: possible in the very beggining of input*/
     detected = TRUE;		/* assume it's in the short-pause duration */
   } else if (count > 0) {	/* many words found --- check if maximum is sp */
-    p = winfo->wseq[tremax->wid][0]->name;
-    if (is_sil(p)) {
+    if (is_sil(tremax->wid, wchmm->winfo, wchmm->hmminfo)) {
       detected = TRUE;
     }
   }
@@ -753,7 +770,7 @@ detect_end_of_segment(BACKTRELLIS *backtrellis, int time, WORD_INFO *winfo)
 #ifdef SP_BREAK_DEBUG
       printf(">> segment [%d..%d]\n", sparea_start, time-1);
 #else
-      j_printerr("|");
+      if (idc_on) j_printerr("|");
 #endif /* SP_BREAK_DEBUG */
       /* store begging frame of the segment */
       sparea_start = tmp_sparea_start;
@@ -836,8 +853,8 @@ init_nodescore(HTK_Param *param, WCHMM_INFO *wchmm)
     /* $BJ8=*N;C18l(B(silE,$B6gE@(B(IPA$B%b%G%k(B))$B$J$i!$(BsilB $B$G3+;O(B */
     /* initial word = best last word hypothesis on the last segment */
     /* if silE or sp, begin with silB */
-    if (sp_break_last_word == wchmm->winfo->tail_silwid ||
-	sp_break_last_word == 4) { /* sp: super ad-hoc, need fix... */
+    /*if (is_sil(sp_break_last_word, wchmm->winfo, wchmm->hmminfo)) {*/
+    if (sp_break_last_word == wchmm->winfo->tail_silwid) {
       beginword = wchmm->winfo->head_silwid;
       bos.wid = WORD_INVALID;	/* reset initial word context */
     } else {
@@ -1546,7 +1563,7 @@ get_back_trellis_proceed(
 
 #ifdef SP_BREAK_CURRENT_FRAME
   /* $B%7%g!<%H%]!<%:%;%0%a%s%F!<%7%g%s(B: $BD>A0%U%l!<%`$G%;%0%a%s%H$,@Z$l$?$+$I$&$+%A%'%C%/(B */
-  if (detect_end_of_segment(backtrellis, t-1, wchmm->winfo)) {
+  if (detect_end_of_segment(backtrellis, t-1, wchmm)) {
     /* $B%;%0%a%s%H=*N;8!CN(B: $BBh#1%Q%9$3$3$GCfCG(B */
     return FALSE;		/* segment: [sparea_start..t-2] */
   }
@@ -1664,12 +1681,18 @@ finalize_segment(BACKTRELLIS *backtrellis, HTK_Param *param, int len)
      param[0..len-1] -> param
      [sparea_start...len-1] overlapped
   */
+
+  /* be aware that in realtime mode, the last f_delay frames has
+     incomplete samples of 26 dims! As only the 25 dims are copied
+     for speech input, we have to re-culculate delta and power at
+     RealTimeResume.
+   */
   if (len != param->samplenum) {
+
+    VERMES("segmented: processed length=%d\n", len);
+    VERMES("segmented: next decoding will restart from %d\n", sparea_start);
+    
     /* copy rest parameters for next process */
-#ifdef SP_BREAK_DEBUG
-    printf("[%d..%d]->[%d..%d] %d\n", sparea_start, param->samplenum-1,
-	   0, param->samplenum-sparea_start-1, len);
-#endif
     rest_param = new_param();
     memcpy(&(rest_param->header), &(param->header), sizeof(HTK_Param_Header));
     rest_param->samplenum = param->samplenum - sparea_start;
