@@ -6,7 +6,7 @@
 
 /* extern.h --- external functions prototype definitions */
 
-/* $Id: extern.h,v 1.11 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: extern.h,v 1.14 2003/12/22 07:00:08 ri Exp $ */
 
 /* should be included after all include files */
 
@@ -43,6 +43,7 @@ void get_back_trellis_end(HTK_Param *param, WCHMM_INFO *wchmm, BACKTRELLIS *back
 void get_back_trellis(HTK_Param *param, WCHMM_INFO *wchmm, BACKTRELLIS *backtrellis, LOGPROB *backmax);
 LOGPROB finalize_1st_pass(BACKTRELLIS *backtrellis, WORD_INFO *winfo, int len);
 #ifdef SP_BREAK_CURRENT_FRAME
+boolean is_sil(WORD_ID w, WORD_INFO *winfo, HTK_HMM_INFO *hmm);
 void finalize_segment(BACKTRELLIS *backtrellis, HTK_Param *param, int len);
 #endif
 
@@ -130,6 +131,7 @@ char *get_line(char *prompt);
 void check_specs();	/* check needed parameter */
 void print_setting();		/* output current setting */
 void print_info();		/* output current gammar info */
+int adin_cut_callback_store_buffer(SP16 *now, int len);
 /* m_usage.c */
 void opt_terminate();
 void usage();
@@ -154,12 +156,17 @@ void adin_initialize();
 void final_fusion();
 /* result_tty.c */
 void setup_result_tty();
+void ttyout_status_recready();
+void ttyout_status_recstart();
+void ttyout_status_recend();
+void ttyout_status_param(HTK_Param *p);
 /* result_msock.c */
 void setup_result_msock();
 void decode_output_selection(char *str);
 void msock_status_recready();
 void msock_status_recstart();
 void msock_status_recend();
+void msock_status_param(HTK_Param *p);
 
 /* hmm_check.c */
 void hmm_check(HTK_HMM_INFO *hmminfo, WORD_INFO *winfo);
@@ -169,5 +176,13 @@ void record_sample_open();
 void record_sample_write(SP16 *speech, int samplenum);
 void record_sample_close();
 
+/* visual.c */
+void visual_init();
+void visual_show(BACKTRELLIS *bt);
+void visual2_init(int maxhypo);
+void visual2_popped(NODE *n, int popctr);
+void visual2_next_word(NODE *next, NODE *prev, int popctr);
+void visual2_best(NODE *now, WORD_INFO *winfo);
+
 /* main.c */
 void main_recognition_loop();
