@@ -7,7 +7,7 @@
 /* m_fusion.c --- initialize all models, work area and parameters
                   to make up system */
 
-/* $Id: m_fusion.c,v 1.14 2003/10/02 03:05:02 ri Exp $ */
+/* $Id: m_fusion.c,v 1.16 2003/12/22 09:38:55 ri Exp $ */
 
 #include <julius.h>
 
@@ -31,6 +31,12 @@ initialize_HMM()
       j_printerr("Error: for direct speech input, only 25(26)-dim. MFCC_{0|E}_D[_N]_Z is supported\n");
       j_error("Error: with this HMM, input must be given in HTK parameter file via \"-input mfcfile\"\n");
     }
+    /* check if CMN is required on this model */
+    if (hmminfo->opt.param_type & F_CEPNORM) {
+      cmn_required = TRUE;
+    } else {
+      cmn_required = FALSE;
+    }
   }
   /* check if tied_mixture */
   if (hmminfo->is_tied_mixture && hmminfo->codebooknum <= 0) {
@@ -59,11 +65,8 @@ initialize_HMM()
     }
   }
   /* set which iwcd1 method to use */
-  if (iwcdavg_flag) {
-    hmminfo->prefer_cdset_avg = TRUE;
-  } else {
-    hmminfo->prefer_cdset_avg = FALSE;
-  }
+  hmminfo->cdset_method = iwcdmethod;
+  hmminfo->cdmax_num = iwcdmaxn;
 }
 
 /* initialize HMM for Gaussian Mixture Selection */
