@@ -6,7 +6,7 @@
 
 /* m_info.c --- output system information */
 
-/* $Id: m_info.c,v 1.25 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: m_info.c,v 1.32 2004/01/21 12:23:12 ri Exp $ */
 
 #include <julius.h>
 
@@ -199,9 +199,13 @@ print_info()
   j_printf("\t      1st pass decoding = ");
   if (force_realtime_flag) j_printf("(forced) ");
   if (realtime_flag) {
-    j_printf("on-the-fly with last CMN\n");
+    j_printf("on-the-fly");
+    if (cmn_required) j_printf(" with last CMN");
+    j_printf("\n");
   } else {
-    j_printf("batch with sentence CMN\n");
+    j_printf("batch");
+    if (cmn_required) j_printf(" with sentence CMN");
+    j_printf("\n");
   }
   if (cmnload_filename) {
     if (cmn_loaded) {
@@ -265,10 +269,16 @@ print_info()
     j_printf("\t IWCD handling:\n");
 #ifdef PASS1_IWCD
     j_printf("\t   1st pass: approximation ");
-    if (hmminfo->prefer_cdset_avg) {
+    switch(hmminfo->cdset_method) {
+    case IWCD_AVG:
       j_printf("(use average prob. of same LC)\n");
-    } else {
+      break;
+    case IWCD_MAX:
       j_printf("(use max. prob. of same LC)\n");
+      break;
+    case IWCD_NBEST:
+      j_printf("(use %d-best of same LC)\n", hmminfo->cdmax_num);
+      break;
     }
 #else
     j_printf("\t   1st pass: ignored\n");
@@ -374,7 +384,7 @@ print_info()
     j_printf("microphone\n");
   }
   if (speech_input != SP_MFCFILE) {
-    if (speech_input == SP_RAWFILE || speech_input == SP_STDIN) {
+    if (speech_input == SP_RAWFILE || speech_input == SP_STDIN || speech_input == SP_ADINNET) {
       j_printf("\t         sampling freq. = %d Hz required\n", smpFreq);
     } else {
       j_printf("\t         sampling freq. = %d Hz\n", smpFreq);
@@ -407,6 +417,17 @@ print_info()
     } else {
       j_printf("\t        silence cutting = off\n");
     }
+    if (use_zmean) {
+      j_printf("\t       remove DC offset = on");
+      if (speech_input == SP_RAWFILE) {
+	j_printf(" (will compute for each file)\n");
+      } else {
+	j_printf(" (will compute from first %.1f sec)\n",
+		 (float)ZMEANSAMPLES / (float)smpFreq);
+      }
+    } else {
+      j_printf("\t       remove DC offset = off\n");
+    }
   }
 #ifdef SP_BREAK_CURRENT_FRAME
   j_printf("\tshort pause segmentation= on\n");
@@ -433,14 +454,16 @@ print_info()
 
 #ifdef USE_MIC
   if (realtime_flag) {
-    if (cmn_loaded) {
-      j_printf("\ninitial CMN parameter loaded from file\n");
-    } else {
-      j_printf("\n");
-      j_printf("\t************************************************************\n");
-      j_printf("\t* NOTICE: The first input may not be correctly recoginized *\n");
-      j_printf("\t*         since no CMN parameter is available on startup.  *\n");
-      j_printf("\t************************************************************\n");
+    if (cmn_required) {
+      if (cmn_loaded) {
+	j_printf("\ninitial CMN parameter loaded from file\n");
+      } else {
+	j_printf("\n");
+	j_printf("\t************************************************************\n");
+	j_printf("\t* NOTICE: The first input may not be correctly recoginized *\n");
+	j_printf("\t*         since no CMN parameter is available on startup.  *\n");
+	j_printf("\t************************************************************\n");
+      }
     }
   }
 #endif
