@@ -6,7 +6,7 @@
 
 /* m_options.c --- process options and set values */
 
-/* $Id: m_options.c,v 1.19 2003/10/02 03:05:02 ri Exp $ */
+/* $Id: m_options.c,v 1.21 2004/01/08 08:42:17 ri Exp $ */
 
 #include <julius.h>
 
@@ -365,6 +365,12 @@ opt_parse(int argc, char *argv[], char *cwd)
     } else if (strmatch(argv[i],"-nostrip")) { /* do not strip zero samples */
       strip_zero_sample = FALSE;
       continue;
+    } else if (strmatch(argv[i],"-zmean")) { /* enable DC offset by zero mean */
+      use_zmean = TRUE;
+      continue;
+    } else if (strmatch(argv[i],"-nozmean")) { /* disable DC offset by zero mean */
+      use_zmean = FALSE;
+      continue;
 #ifdef SP_BREAK_CURRENT_FRAME
     } else if (strmatch(argv[i],"-spdur")) { /* short-pause duration threshold */
       sp_frame_duration = atoi(NEXTARG);
@@ -403,11 +409,15 @@ opt_parse(int argc, char *argv[], char *cwd)
     } else if (strmatch(argv[i],"-iwcd1")) { /* select cross-word triphone computation method */
       tmparg = NEXTARG;
       if (strmatch(tmparg, "max")) { /* use maximum score in triphone variants */
-	iwcdavg_flag = FALSE;
+	iwcdmethod = IWCD_MAX;
       } else if (strmatch(tmparg, "avg")) { /* use average in variants */
-	iwcdavg_flag = TRUE;
+	iwcdmethod = IWCD_AVG;
+      } else if (strmatch(tmparg, "best")) { /* use average in variants */
+	iwcdmethod = IWCD_NBEST;
+	tmparg = NEXTARG;
+	iwcdmaxn = atoi(tmparg);
       } else {
-	j_printerr("%s: -iwcd1: wrong argument (max|avg): %s\n", argv[0], tmparg);
+	j_printerr("%s: -iwcd1: wrong argument (max|avg|best N): %s\n", argv[0], tmparg);
 	opt_terminate();
       }
       continue;
