@@ -6,7 +6,7 @@
 
 /* realtime-1stpass.c --- on-the-fly 1st pass decoding with realtime CMN */
 
-/* $Id: realtime-1stpass.c,v 1.11 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: realtime-1stpass.c,v 1.15 2003/12/22 07:00:08 ri Exp $ */
 
 /* do speech input, make mfcc (attach), viterbi in single loop */
 
@@ -86,7 +86,7 @@ init_para()
   para.ss_alpha   = ssalpha;
   para.ss_floor   = ssfloor;
   /* para.cmn        = FALSE;*/
-  para.cmn        = TRUE;
+  para.cmn        = cmn_required;
   para.enormal    = FALSE;
   para.raw_e      = FALSE;
   para.vec_num    = (para.mfcc_dim + 1) * 2;
@@ -98,10 +98,14 @@ static void
 init_param()
 {
   param = new_param();
-  if (c0_required) {
-    param->header.samptype = F_MFCC | F_ZEROTH | F_DELTA | F_CEPNORM;
+  param->header.samptype = F_MFCC | F_DELTA;
+  if (para.c0) {
+    param->header.samptype |= F_ZEROTH;
   } else {
-    param->header.samptype = F_MFCC | F_ENERGY | F_DELTA | F_CEPNORM;
+    param->header.samptype |= F_ENERGY;
+  }
+  if (para.cmn) {
+    param->header.samptype |= F_CEPNORM;
   }
   param->header.wshift = para.smp_period * para.frameshift;
   param->header.sampsize = para.vec_num * sizeof(VECT); /* not compressed */
@@ -163,6 +167,16 @@ RealTimePipeLinePrepare()
   f_raw = 0;
   f = 0;
   windownum = 0;
+
+  /* if needed, begin recording the incoming speech data to a file */
+  if (record_dirname != NULL) {
+    record_sample_open();
+  }
+  
+#ifdef VISUALIZE
+  /* record data for waveform printing */
+  speechlen = 0;
+#endif
 }
 
 /* main rountine (called for each incoming short segment from adin-cut) */
@@ -181,10 +195,8 @@ RealTimePipeLine(SP16 *Speech, int nowlen) /* Speech[0...nowlen] = input */
   now = 0;
   last_is_segmented = FALSE;
 
-  if (module_mode) {
-    /* tell modules to start recording/processing */
-    if (f_raw == 0) msock_status_recstart();
-  }
+  /* output start recording/processing message */
+  if (f_raw == 0) status_recstart();
 
 #ifdef RDEBUG
   printf("got %d samples\n", nowlen);
@@ -195,6 +207,11 @@ RealTimePipeLine(SP16 *Speech, int nowlen) /* Speech[0...nowlen] = input */
     record_sample_write(Speech, nowlen);
   }
 
+#ifdef VISUALIZE
+  /* record data for waveform printing */
+  adin_cut_callback_store_buffer(Speech, nowlen);
+#endif
+
   while (now < nowlen) {	/* till whole input is processed */
     /* fill as many as possible */
     for(i = min(windowlen - windownum, nowlen - now); i > 0 ; i--)
@@ -294,6 +311,19 @@ RealTimeResume()
   param->parvec = (VECT **)myrealloc(param->parvec, sizeof(VECT *) * maxframelen);
   /* set pointer for resuming */
   f_raw = param->samplenum - 1;
+
+  /* re-allocate [f -> f_raw] for work area */
+  for (t = f_raw; t > f_raw - f_delay && t >= 0; t--) {
+    param->parvec[t] = (VECT *)myrealloc(param->parvec[t], sizeof(VECT) * para.vec_num);
+  }
+
+  /* re-compute delta (that has been lost in the copying process of param */
+  if (f_raw >= para.delWin) {
+    for (t = f_raw - para.delWin; t > f_raw - f_delay && t >= 0; t--) {
+      WMP_Delta(param->parvec, t, f_raw+1, para);
+    }
+  }
+  
   if (f_raw >= f_delay) {
     /* there are left params in previous call, so recognize it first */
     f = f_raw - f_delay;
@@ -343,8 +373,7 @@ RealTimeParam(LOGPROB *backmax)
 #ifdef SP_BREAK_CURRENT_FRAME
     finalize_segment(&backtrellis, param, last_time);
 #endif
-    /* update CMN vector for next speech */
-    if(para.cmn) CMN_realtime_update();
+    /*if(para.cmn) CMN_realtime_update();*/
     /* return obtained parameter for 2nd pass */
     return(param);
   }
