@@ -6,7 +6,7 @@
 
 /* search.h --- data structure for 2nd pass */
 
-/* $Id: search.h,v 1.5 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: search.h,v 1.6 2003/12/11 07:32:43 ri Exp $ */
 
 #ifndef __SENT_SEARCH_H__
 #define __SENT_SEARCH_H__
@@ -24,6 +24,16 @@ typedef struct __nextword__ {
   TRELLIS_ATOM *tre;		/* pointer to trellis word corresponding to this word */
 } NEXTWORD;
 
+#ifdef VISUALIZE
+/* store popped hypo info here (unlike NODE, this data are linked) */
+typedef struct __popnode__ {
+  TRELLIS_ATOM *tre;		/* last referred trellis word */
+  LOGPROB score;		/* total score (g(x)+h(x)) */
+  struct __popnode__ *last;	/* link to previous word context */
+  struct __popnode__ *next;	/* list pointer to next structure */
+} POPNODE;
+#endif /* VISUALIZE */
+
 /* $BItJ,J82>@b(B */
 /* sentence hypothesis */
 typedef struct __node__ {
@@ -61,6 +71,9 @@ typedef struct __node__ {
   LOGPROB cmscore[MAXSEQNUM];	/* hold CM score of each word */
 #endif /* CM_MULTIPLE_ALPHA */
 #endif /* CONFIDENCE_MEASURE */
+#ifdef VISUALIZE
+  POPNODE *popnode;		/* pointer to popped node info */
+#endif
 } NODE;
 
 /*
