@@ -7,7 +7,7 @@
 /* search_bestfirst_v1.c --- hypothesis handling and scoring functions
    for backscan algorithm */
 
-/* $Id: search_bestfirst_v1.c,v 1.9 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: search_bestfirst_v1.c,v 1.11 2003/12/11 07:32:43 ri Exp $ */
 
 #include <julius.h>
 #ifndef PASS2_STRICT_IWCD
@@ -71,6 +71,9 @@ cpy_node(NODE *dst, NODE *src)
   }
 #ifdef USE_NGRAM
   dst->totallscore = src->totallscore;
+#endif
+#ifdef VISUALIZE
+  dst->popnode = src->popnode;
 #endif
   return(dst);
 }
@@ -104,6 +107,10 @@ newnode()
     tmp->g[i] = LOG_ZERO;
     if (ccd_flag) tmp->g_prev[i] = LOG_ZERO;
   }
+#ifdef VISUALIZE
+  tmp->popnode = NULL;
+#endif
+  tmp->tre = NULL;
 
   return(tmp);
 }
@@ -231,7 +238,7 @@ scan_word(NODE *now, HTK_Param *param)
   A_CELL *ac;
   WORD_ID word;
   LOGPROB tmpmax, tmptmp, score1;
-  int startt = 0;
+  int startt = 0, endt;
   int wordhmmnum;
   LOGPROB tmpmax2 = LOG_ZERO;
   int phmmlen;
@@ -556,6 +563,9 @@ scan_word(NODE *now, HTK_Param *param)
        beginning scanned */
     now->g[t] = wordtrellis[t][0];
 
+    /* store the number of last computed frame */
+    if (node_exist_p) endt = t;
+    
     /* scan$B$7$?C18l$NBh#1%Q%9$G$N;OC<;~9o$h$j@h$^$G(B t $B$,?J$s$G$*$j!$$+$D(B
        $B$3$N(B t $B$K$*$$$F%9%3%"%(%s%Y%m!<%W$K$h$C$F@8$-;D$C$?%N!<%I$,0l$D$b(B
        $BL5$+$C$?$J$i$P(B,$B$3$N%U%l!<%`$G7W;;$rBG$A@Z$j$=$l0J>e@h(B([0..t-1])$B$O(B
@@ -576,7 +586,7 @@ scan_word(NODE *now, HTK_Param *param)
     
   } /* end of time loop */
   
-  if (debug2_flag) j_printf("scanned: [%3d-%3d]\n",t+1,startt);
+  if (debug2_flag) j_printf("scanned: [%3d-%3d]\n", endt, startt);
 
  end_of_scan:
   /* $B<!2s(B backscan $B$N$?$a$N>pJs3JG<(B */
@@ -791,6 +801,7 @@ next_word(NODE *now, NODE *new,	NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
 	new->score = totalscore;
 	new->bestt = t;
 	new->estimated_next_t = tre->begintime - 1;
+	new->tre  =  tre;
       }
     }
   } else {
