@@ -7,7 +7,7 @@
 /* search_bestfirst_v2.c --- hypothesis handling and scoring functions
    for nextscan algorithm */
 
-/* $Id: search_bestfirst_v2.c,v 1.9 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: search_bestfirst_v2.c,v 1.10 2003/12/11 07:32:43 ri Exp $ */
 
 /* by "fast" setting (default), search_bestfirst_v1.c is used for faster
    decoding.  Please specify option "--enable-setup=standard" or
@@ -70,6 +70,9 @@ cpy_node(NODE *dst, NODE *src)
   }
 #ifdef USE_NGRAM
   dst->totallscore = src->totallscore;
+#endif
+#ifdef VISUALIZE
+  dst->popnode = src->popnode;
 #endif
   return(dst);
 }
@@ -100,6 +103,9 @@ newnode()
   for(i=0;i<peseqlen;i++) {
     tmp->g[i] = LOG_ZERO;
   }
+#ifdef VISUALIZE
+  tmp->popnode = NULL;
+#endif
 
   return(tmp);
 }
@@ -638,6 +644,7 @@ next_word(NODE *now, NODE *new, NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
 	new->score = totalscore;
 	new->bestt = t;
 	new->estimated_next_t = tre->begintime - 1;
+	new->tre = tre;
       }
     }
   } else {
@@ -663,6 +670,7 @@ next_word(NODE *now, NODE *new, NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
       new->score = totalscore;
       new->bestt = t;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
     }
   }
   /* 2. search bckward */
@@ -679,6 +687,7 @@ next_word(NODE *now, NODE *new, NEXTWORD *nword, HTK_Param *param, BACKTRELLIS *
       new->score = totalscore;
       new->bestt = t;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
     }
   }
 
@@ -750,6 +759,7 @@ start_word(
       }
       new->score = new->g[peseqlen-1] + tre->backscore + tmpp;
       new->estimated_next_t = tre->begintime - 1;
+      new->tre = tre;
       break;
     }
   }
