@@ -6,7 +6,7 @@
 
 /* htk_hmm.h --- HMM structure for HTK format */
 
-/* $Id: htk_hmm.h,v 1.7 2003/09/29 06:01:22 ri Exp $ */
+/* $Id: htk_hmm.h,v 1.9 2003/12/22 09:36:07 ri Exp $ */
 
 #ifndef __SENT_HTK_HMM_2_H__
 #define __SENT_HTK_HMM_2_H__
@@ -18,6 +18,8 @@
 #define currentis(A)  (!strcasecmp(A, rdhmmdef_token))
 #define NoTokErr(S)      if (!rdhmmdef_token) rderr(S)
 
+enum{IWCD_MAX,IWCD_AVG,IWCD_NBEST};
+
 
 #define MAX_STATE_NUM 65535	/* allowed maximum state id = unsigned short */
 
@@ -187,7 +189,8 @@ typedef struct {
   /* misc. model info */
   boolean is_triphone;		/* TRUE if this is triphone model */
   boolean is_tied_mixture;	/* TRUE if this is tied-mixture model */
-  boolean prefer_cdset_avg;	/* compute average of lcdset instead of maximum */
+  short cdset_method; /* compute method of lcdset */
+  short cdmax_num;		/* num for IWCD_NBEST */
   HMM_Logical *sp;		/* short pause model */
   
   int totalmixnum;		/* total mixture num */
@@ -214,24 +217,30 @@ void set_global_opt(FILE *fp, HTK_HMM_INFO *hmm);
 char *get_cov_str(short covtype);
 char *get_dur_str(short durtype);
 /* rdhmmdef_trans.c */
+void trans_add(HTK_HMM_INFO *hmm, HTK_HMM_Trans *new);
 HTK_HMM_Trans *get_trans_data(FILE *, HTK_HMM_INFO *);
 void def_trans_macro(char *, FILE *, HTK_HMM_INFO *);
 /* rdhmmdef_state.c */
 HTK_HMM_State *get_state_data(FILE *, HTK_HMM_INFO *);
 void def_state_macro(char *, FILE *, HTK_HMM_INFO *);
 HTK_HMM_State *state_lookup(HTK_HMM_INFO *hmm, char *keyname);
+void state_add(HTK_HMM_INFO *hmm, HTK_HMM_State *new);
 /* rdhmmdef_dens.c */
 HTK_HMM_Dens *get_dens_data(FILE *, HTK_HMM_INFO *);
 void def_dens_macro(char *, FILE *, HTK_HMM_INFO *);
 HTK_HMM_Dens *dens_lookup(HTK_HMM_INFO *hmm, char *keyname);
+void dens_add(HTK_HMM_INFO *hmm, HTK_HMM_Dens *new);
 /* rdhmmdef_var.c */
 HTK_HMM_Var *get_var_data(FILE *, HTK_HMM_INFO *);
 void def_var_macro(char *, FILE *, HTK_HMM_INFO *);
-/* rdhmmdef_hmm.c */
+void var_add(HTK_HMM_INFO *hmm, HTK_HMM_Var *new);
+/* rdhmmdef_data.c */
 void def_HMM(char *, FILE *, HTK_HMM_INFO *);
 HTK_HMM_Data *htk_hmmdata_new();
+void htk_hmmdata_add(HTK_HMM_INFO *hmm, HTK_HMM_Data *new);
 /* rdhmmdef_tiedmix.c */
 void tmix_read(FILE *fp, HTK_HMM_State *state, HTK_HMM_INFO *hmm);
+void codebook_add(HTK_HMM_INFO *hmm, GCODEBOOK *new);
 /* rdhmmdef_regtree.c */
 void def_regtree_macro(char *name, FILE *fp, HTK_HMM_INFO *hmm);
 /* rdhmmdef_hmmlist.c */
@@ -281,4 +290,8 @@ boolean check_param_basetype(HTK_HMM_INFO *hmm, HTK_Param *pinfo);
 HTK_Param *new_param_check_and_adjust(HTK_HMM_INFO *hmm, HTK_Param *pinfo, boolean vflag);
 
 
+/* binary format */
+boolean write_binhmm(FILE *fp, HTK_HMM_INFO *hmm);
+boolean read_binhmm(FILE *fp, HTK_HMM_INFO *hmm);
+
 #endif /* __SENT_HTK_HMM_2_H__ */
