@@ -6,7 +6,7 @@
 
 /* init_phmm.c --- read in hmmdefs file & initialize */
 
-/* $Id: init_phmm.c,v 1.5 2003/09/29 06:01:23 ri Exp $ */
+/* $Id: init_phmm.c,v 1.6 2003/12/08 03:31:17 ri Exp $ */
 
 #include <sent/stddefs.h>
 #include <sent/htk_hmm.h>
@@ -27,18 +27,37 @@ void
 init_hmminfo(HTK_HMM_INFO *hmminfo, char *hmmfilename, char *namemapfile)
 {
   FILE *fp;
+  boolean ok_p;
+
+  ok_p = FALSE;
 
-  j_printerr("Reading in HMM definition...");
   /* read hmmdef file */
+  j_printerr("Reading in HMM definition...");
+  /* first, try ascii format */
   if ((fp = fopen_readfile(hmmfilename)) == NULL) {
     j_error("failed to open %s\n",hmmfilename);
   }
-  if (rdhmmdef(fp, hmminfo) == FALSE) {
-    j_error("read error in %s\n",hmmfilename);
+  if (rdhmmdef(fp, hmminfo) == TRUE) {
+    ok_p = TRUE;
   }
   if (fclose_readfile(fp) < 0) {
     j_error("failed to close %s\n", hmmfilename);
   }
+  if (ok_p == FALSE) {
+    /* second, try binary format */
+    if ((fp = fopen_readfile(hmmfilename)) == NULL) {
+      j_error("failed to open %s\n",hmmfilename);
+    }
+    if (read_binhmm(fp, hmminfo) == TRUE) {
+      ok_p = TRUE;
+    }
+    if (fclose_readfile(fp) < 0) {
+      j_error("failed to close %s\n", hmmfilename);
+    }
+  }
+  if (ok_p == FALSE) {
+    j_error("failed to read %s\n", hmmfilename);
+  }
 
   j_printerr("   defined HMMs: %5d\n", hmminfo->totalhmmnum);
 
