@@ -6,7 +6,7 @@
 
 /* rdhmmdef.c --- read in HTK format HMM definition file (main) */
 
-/* $Id: rdhmmdef.c,v 1.5 2003/09/29 06:01:23 ri Exp $ */
+/* $Id: rdhmmdef.c,v 1.7 2003/12/22 09:37:40 ri Exp $ */
 
 #include <sent/stddefs.h>
 #include <sent/htk_param.h>
@@ -116,7 +116,8 @@ init_hmm(HTK_HMM_INFO *hmm)
   hmm->totallogicalnum = 0;
   hmm->is_triphone = FALSE;
   hmm->is_tied_mixture = FALSE;
-  hmm->prefer_cdset_avg = FALSE;
+  hmm->cdset_method = IWCD_NBEST;
+  hmm->cdmax_num = 3;
   hmm->totalpseudonum = 0;
 }
 
@@ -136,7 +137,7 @@ rdhmmdef(FILE *fp, HTK_HMM_INFO *hmm)
   /* the toplevel loop */
   while (rdhmmdef_token != NULL) {/* break on EOF */
     if (rdhmmdef_token[0] != '~') { /* toplevel commands are always macro */
-      rderr(NULL);
+      return FALSE;
     }
     macrosw = rdhmmdef_token[1];
     read_token(fp);		/* read next token after the "~.."  */
@@ -177,9 +178,11 @@ rdhmmdef(FILE *fp, HTK_HMM_INFO *hmm)
     }
   }
 
+  j_printerr("(ascii)...");
+  
   /* check limitation */
   if (check_all_hmm_limit(hmm)) {
-    j_printerr("limit check passed...\n");
+    j_printerr("limit check passed\n");
   } else {
     j_error("Error: cannot use this HMM for system limitation.\n");
   }
