@@ -1,10 +1,12 @@
-/* Copyright (c) 1991-2002 Doshita Lab. Speech Group, Kyoto University */
-/* Copyright (c) 2000-2002 Speech and Acoustics Processing Lab., NAIST */
-/*   All rights reserved   */
+/*
+ * Copyright (c) 1991-2003 Kyoto University
+ * Copyright (c) 2000-2003 NAIST
+ * All rights reserved
+ */
 
 /* rdhmmdef_var.c --- read in hmmdefs (variance) */
 
-/* $Id: rdhmmdef_var.c,v 1.3 2002/09/11 22:01:50 ri Exp $ */
+/* $Id: rdhmmdef_var.c,v 1.5 2003/12/08 03:31:17 ri Exp $ */
 
 /* currenty cannot treat other sub macros (~u,~i,~x) */
 
@@ -30,7 +32,7 @@ var_new()
 }
 
 /* register */
-static void
+void
 var_add(HTK_HMM_INFO *hmm, HTK_HMM_Var *new)
 {
   HTK_HMM_Var *match;
