@@ -6,7 +6,7 @@
 
 /* vsegment.c --- generic routine to do viterbi segmentation */
 
-/* $Id: vsegment.c,v 1.6 2003/09/29 06:01:23 ri Exp $ */
+/* $Id: vsegment.c,v 1.7 2004/01/13 08:38:02 ri Exp $ */
 
 /* any segmentatino unit is allowed: segmentation point should be specified by sequence of HMM number to pickup */
 
@@ -19,6 +19,7 @@ typedef struct __seg_token__ {
   int last_end_frame;
   LOGPROB last_end_score;
   struct __seg_token__ *next;
+  struct __seg_token__ *list;
 } SEGTOKEN;
 
 LOGPROB				/* returns the acoustic score */
@@ -40,7 +41,7 @@ viterbi_segment(HMM *hmm,	/* concatinated sentence HMMs */
   int tl,tn;
   LOGPROB tmpsum;
   A_CELL *ac;
-  SEGTOKEN *newtoken, *token, *tmptoken;
+  SEGTOKEN *newtoken, *token, *tmptoken, *root;
   LOGPROB result_score;
   LOGPROB maxscore, minscore;	/* for debug */
   int maxnode;			/* for debug */
@@ -75,6 +76,7 @@ viterbi_segment(HMM *hmm,	/* concatinated sentence HMMs */
   /* initialize node buffers */
   tn = 0;
   tl = 1;
+  root = NULL;
   for (i=0;i<2;i++){
     nodescore[i] = (LOGPROB *)mymalloc(hmm->len * sizeof(LOGPROB));
     tokenp[i] = (SEGTOKEN **)mymalloc(hmm->len * sizeof(SEGTOKEN *));
@@ -85,6 +87,8 @@ viterbi_segment(HMM *hmm,	/* concatinated sentence HMMs */
     newtoken->last_id = -1;
     newtoken->last_end_frame = -1;
     newtoken->last_end_score = 0.0;
+    newtoken->list = root;
+    root = newtoken;
     newtoken->next = NULL;
     tokenp[tn][n] = newtoken;
   }
@@ -134,6 +138,8 @@ viterbi_segment(HMM *hmm,	/* concatinated sentence HMMs */
 	  newtoken->last_id = u_end[from_node[n]];
 	  newtoken->last_end_frame = t-1;
 	  newtoken->last_end_score = nodescore[tl][from_node[n]];
+	  newtoken->list = root;
+	  root = newtoken;
 	  newtoken->next = tokenp[tl][from_node[n]];
 	  tokenp[tn][n] = newtoken;
 	} else {
@@ -208,28 +214,11 @@ viterbi_segment(HMM *hmm,	/* concatinated sentence HMMs */
   free(u_start);
   free(u_end);
   free(from_node);
-  for (n = 0; n < hmm->len; n++) {
-    token = tokenp[tn][n];
-    while (token) {
-      for (i = n + 1; i < hmm->len; i++) {
-	if (tokenp[tn][i] == token) {
-	  tokenp[tn][i] = NULL;
-	} else {
-	  tmptoken = tokenp[tn][i];
-	  while (tmptoken) {
-	    if (tmptoken->next == token) {
-	      tmptoken->next = NULL;
-	      break;
-	    } else {
-	      tmptoken = tmptoken->next;
-	    }
-	  }
-	}
-      }
-      tmptoken = token->next;
-      free(token);
-      token = tmptoken;
-    }
+  token = root;
+  while(token) {
+    tmptoken = token->list;
+    free(token);
+    token = tmptoken;
   }
   for (i=0;i<2;i++) {
     free(nodescore[i]);
